@@ -322,11 +322,10 @@ public class ResourcesListViewPanel extends FramedPanel {
 
 		});
 		toolBar.add(comboSort);
-		
+
 		//
 		statusBar = new ToolBar();
-		
-		
+
 		//
 		ResourcesListViewBundle.INSTANCE.css().ensureInjected();
 
@@ -404,7 +403,7 @@ public class ResourcesListViewPanel extends FramedPanel {
 		main.add(toolBar, new VerticalLayoutData(1, -1));
 		main.add(listView, new VerticalLayoutData(1, 1));
 		main.add(statusBar, new VerticalLayoutData(1, -1));
-		
+
 		details = new ResourcesListViewDetailPanel(this);
 
 		BorderLayoutData centerData = new BorderLayoutData();
@@ -536,12 +535,16 @@ public class ResourcesListViewPanel extends FramedPanel {
 						public void onSuccess(
 								ArrayList<ResourceTDDescriptor> result) {
 							Log.debug("Resources loaded " + result.size());
-							if(result!=null&&result.size()>0){
+							if (result != null && result.size() > 0) {
 								statusBar.clear();
-								statusBar.add(new LabelToolItem("Resources: "+result.size()));
+								statusBar
+										.add(new LabelToolItem(
+												"Number of Resources: "
+														+ result.size()));
+
 							} else {
 								statusBar.clear();
-								statusBar.add(new LabelToolItem("No Resource found"));
+								statusBar.add(new LabelToolItem("No Resource"));
 							}
 							try {
 								callback.onSuccess(result);
@@ -921,19 +924,19 @@ public class ResourcesListViewPanel extends FramedPanel {
 			final ResourceTDDescriptor resourceTDDescriptor) {
 		ResourceTD resource = resourceTDDescriptor.getResourceTD();
 		if (resource instanceof InternalURITD) {
-			
-			
+
 			InternalURITD genericFileResourceTD = (InternalURITD) resource;
-			String name=resourceTDDescriptor.getName();
-			MimeTypeSupport mts=MimeTypeSupport.getMimeTypeSupportFromMimeName(genericFileResourceTD.getMimeType());
-			if(mts!=null){
-				name=name+mts.getExtension();
-			} 
-		
+			String name = resourceTDDescriptor.getName();
+			MimeTypeSupport mts = MimeTypeSupport
+					.getMimeTypeSupportFromMimeName(genericFileResourceTD
+							.getMimeType());
+			if (mts != null) {
+				name = name + mts.getExtension();
+			}
+
 			UriResolverSession uriResolverSession = new UriResolverSession(
 					genericFileResourceTD.getId(), ApplicationType.SMP_ID,
-					name,
-					genericFileResourceTD.getMimeType());
+					name, genericFileResourceTD.getMimeType());
 
 			TDGWTServiceAsync.INSTANCE.getUriFromResolver(uriResolverSession,
 					new AsyncCallback<String>() {
